using Unity.Lifetime;
using Unity;
using ProjectHotel.Repositories;
using ProjectHotel.Repositories.Implementations;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Logging;
using Serilog;
using Unity.Microsoft.Logging;

namespace ProjectHotel
{
    internal static class Program
    {
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            Application.Run(CreateContainer().Resolve<FormHotelForAthletes>());
        }
        private static IUnityContainer CreateContainer()
        {
            var container = new UnityContainer();

            container.AddExtension(new LoggingExtension(CreateLoggerFactory()));
            container.RegisterType <IConnectionString, ConnectionString> (new SingletonLifetimeManager());
            container.RegisterType<IAthleteRepository, AthleteRepository>(new TransientLifetimeManager());
            container.RegisterType<ICleaningRoomRepository, CleaningRoomRepository>(new TransientLifetimeManager());
            container.RegisterType<IHotelRepository, HotelRepository>(new TransientLifetimeManager());
            container.RegisterType<IPlacingAthleteRepository, PlacingAthleteRepository>(new TransientLifetimeManager());
            container.RegisterType<IRoomRepository, RoomRepository>(new TransientLifetimeManager());

            return container;
        }
        private static LoggerFactory CreateLoggerFactory()
        {
            var loggerFactory = new LoggerFactory();
            loggerFactory.AddSerilog(new LoggerConfiguration()
            .ReadFrom.Configuration(new ConfigurationBuilder()
            .SetBasePath(Directory.GetCurrentDirectory())
            .AddJsonFile("appsettings.json")
            .Build())
            .CreateLogger());
            return loggerFactory;
        }
    }
}