﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using ProjectHotel.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectHotel.Repositories.Implementations;

internal class CleaningRoomRepository : ICleaningRoomRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<CleaningRoomRepository> _logger;

    public CleaningRoomRepository(IConnectionString connectionString, ILogger<CleaningRoomRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }
    public IEnumerable<CleaningRoom> ReadCleaningRooms(int? id = null, int? roomId = null)
    {
        _logger.LogInformation("Получение всех объектов");

        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            connection.Open();
            var querySelect = @"SELECT * FROM CleaningRoom";
            var cleaningRoom = connection.Query<CleaningRoom>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}", JsonConvert.SerializeObject(cleaningRoom));
            return cleaningRoom;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при получении всех объектов");
            throw;
        }
    }
    public void CreateCleaningRoom(CleaningRoom cleaningRoom)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}", JsonConvert.SerializeObject(cleaningRoom));

        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
                INSERT INTO CleaningRoom (RoomId, CleaningDate)
                VALUES (@RoomId, @CleaningDate);
            ";
            connection.Execute(queryInsert, cleaningRoom);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }
    public CleaningRoom ReadCleaningRoomById(int id)
    {
        _logger.LogInformation("Получение объекта по идентификатору");
        _logger.LogDebug("Объект: {id}", id);

        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"
                SELECT * FROM CleaningRoom WHERE Id = @Id;
            ";
            var cleaningRoom = connection.QueryFirst<CleaningRoom>(querySelect, new { id });
            _logger.LogDebug("Найденный объект: {json}", JsonConvert.SerializeObject(cleaningRoom));
            return cleaningRoom;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при поиске объекта");
            throw;
        }
    }
}
